@@ -56,10 +56,13 @@ class AmbiguousPathError(Exception):
 
 class Credentials(google.oauth2.credentials.Credentials,
                 oauth2client.client.Credentials):
+    #TODO get rid of oauth2client dependency
     @classmethod
     def from_json(cls, json_string):
         a = json.loads(json_string)
-        return cls.from_authorized_user_info(a, a['scopes'])
+        credentials = cls.from_authorized_user_info(a, a['scopes'])
+        credentials.token = a['access_token']
+        return credentials
 
     @classmethod
     def from_authorized_user_file(cls, filename):
@@ -157,8 +160,10 @@ class DriveItem(ABC):
                                 body=metadata,
                                 fields=','.join(metadata.keys()),
                                 ).execute()
+        #TODO update local array
 
     def meta_get(self, fields: str) -> dict:
+        #TODO cache metadata
         return self.drive.service.files().get(fileId=self.id, fields=fields).execute()
 
     def refresh(self):
@@ -435,6 +440,7 @@ class ResumableUploadRequest:
             status, resp = self.service._http.request(self.resumable_uri, method='PUT', headers={'Content-Length':'0', 'Content-Range':upload_range})
             
             if status['status'] not in ('200', '308'):
+                #Should 404 result in a FileNotFound error?
                 raise HttpError(status, resp)
 
             self._range_md5 = hashlib.md5()
@@ -517,13 +523,14 @@ class GoogleDrive(DriveFolder):
             raise NotAuthenticatedError("Could not get requested scopes")
         return Credentials.to_json(creds)
 
-    def __init__(self, creds):
+    def __init__(self, creds, autorefresh=True):
         try:
             self.creds = Credentials.from_json(creds)
         except TypeError:
             self.creds = creds
 
-        if self.creds.expired and self.creds.refresh_token:
+        if self.creds.expired and self.creds.refresh_token \
+                and autorefresh:
             self.creds.refresh(Request())
 
         http = google_auth_httplib2.AuthorizedHttp(self.creds)
